CREATE TABLE UsersBulk (
	EmployeeId	varchar(50),
	LastName varchar(50),
	FirstName varchar(50),
	Department varchar(50),
	CardId varchar(50)
);

BULK INSERT UsersBulk
	FROM 'hasbro_employees.csv'
	WITH (
		FIELDTERMINATOR = ',',
		ROWTERMINATOR = '\n'
	);


DECLARE @employeeId varchar(50)
DECLARE @lastName varchar(50)
DECLARE @firstName varchar(50)
DECLARE @department varchar(50)
DECLARE @cardId varchar(50)

DECLARE temp_cursor CURSOR FOR
	SELECT	EmployeeId,LastName,FirstName,Department,CardId
	FROM	UsersBulk

DECLARE @customerNameAttributeValueNo int
SET @customerNameAttributeValueNo = -1
SELECT	TOP 1 @customerNameAttributeValueNo=AttributeValueNo
FROM	AttributeValues av
			JOIN Attributes a ON a.AttributeNo = av.AttributeNo
WHERE	a.Name='Customer Name'
IF @customerNameAttributeValueNo = -1
BEGIN
	INSERT INTO AttributeValues(AttributeNo,Value,ValueType,ParentAttributeValueNo,ParentEligible,LastModified)
		SELECT	AttributeNo,'Default Customer','string',null,1,GETDATE()
		FROM	Attributes
		WHERE	Name = 'Customer Name'
	SET @customerNameAttributeValueNo = SCOPE_IDENTITY()
END

DECLARE @customerLocationAttributeValueNo int
SET @customerLocationAttributeValueNo = -1
SELECT		TOP 1 @customerLocationAttributeValueNo=AttributeValueNo
FROM		AttributeValues av
				JOIN Attributes a ON a.AttributeNo = av.AttributeNo
WHERE		a.Name='Customer Location'
ORDER BY	AttributeValueNo ASC
IF @customerLocationAttributeValueNo = -1
BEGIN
	INSERT INTO AttributeValues(AttributeNo,Value,ValueType,ParentAttributeValueNo,ParentEligible,LastModified)
		SELECT	TOP 1 AttributeNo,'Default Location','string',@customerNameAttributeValueNo,1,GETDATE()
		FROM	Attributes
		WHERE	Name = 'Customer Location'
	SET @customerLocationAttributeValueNo = SCOPE_IDENTITY()
END

OPEN temp_cursor
FETCH NEXT FROM temp_cursor INTO @employeeId,@lastName,@firstName,@department,@cardId
WHILE @@FETCH_STATUS = 0
BEGIN
	DECLARE @fullName varchar(50)
	SET @fullName = RTRIM(@firstName) + ' ' + RTRIM(@lastName)
	PRINT 'fullName = [' + @fullName + ']'
	
	DECLARE @cardNo int
	SET @cardNo = -1
	SELECT @cardNo=CardNo FROM Cards WHERE Id=@cardId
	IF @cardNo = -1
	BEGIN
		INSERT INTO Cards(Active,Id,PIN,LastModified)
			VALUES(1,@cardId,null,GETDATE())
		SET @cardNo = SCOPE_IDENTITY()
	END
	
	DECLARE @deptNo int
	SET @deptNo = -1
	SELECT	TOP 1 @deptNo=AttributeValueNo
	FROM	AttributeValues av
				JOIN Attributes a ON a.AttributeNo = av.AttributeNo
	WHERE	a.Name='Customer Department' AND av.Value=@department
	IF @deptNo = -1
	BEGIN
		INSERT INTO AttributeValues(AttributeNo,Value,ValueType,ParentAttributeValueNo,ParentEligible,LastModified)
			SELECT	TOP 1 AttributeNo,@department,'string',@customerLocationAttributeValueNo,1,GETDATE()
			FROM	Attributes
			WHERE	Name = 'Customer Department'
		SET @deptNo = SCOPE_IDENTITY()
	END
	
	INSERT INTO Users(Active,Name,CardNo,Id,DeptNo,LastModified)
		VALUES(1,@fullName,@cardNo,@employeeId,@deptNo,GETDATE())

	FETCH NEXT FROM temp_cursor INTO @employeeId,@lastName,@firstName,@department,@cardId
END
CLOSE temp_cursor
DEALLOCATE temp_cursor

DROP TABLE UsersBulk
